@@ -1,4 +1,6 @@
 # -*- coding: utf-8 -*-
 
 from ._pymssql import *
+from .exceptions import *
 from ._pymssql import __version__, __full_version__
+from ._mssql import datetime2
